@@ -13,6 +13,7 @@
 #pylint:disable=redefined-outer-name
 
 import os
+from time import time
 from ..annotations import List, Union
 
 _acceptable_video_formats = ('.mp4', '.avi', '.mov', '.mkv', '.webm')
@@ -36,7 +37,7 @@ __all__ = [
     'dirname'
 ]
 
-def list_images(DIR, recursive=True, use_fullpath=False, show_size=False, verbose=True) -> List[str]:
+def list_images(DIR, recursive=True, use_fullpath=False, verbose=True, every : int = 1000) -> List[str]:
     r"""
         Lists all image files within a specific directory (and sub-directories if `recursive=True`)
     
@@ -44,16 +45,15 @@ def list_images(DIR, recursive=True, use_fullpath=False, show_size=False, verbos
         DIR (str): Directory to search for image files
         recursive (bool): Indicate whether to search all subdirectories as well (default = False)
         use_fullpath (bool): Include full filepaths in the returned list (default = False)
-        show_size (bool): Prints the disk size of the image files (default = False)
     
     Returns:
         image_files (list): List of names (or full filepaths if `use_fullpath=True`) of the image files
 
     """
-    return listdir(DIR=DIR, recursive=recursive, use_fullpath=use_fullpath, ext = _acceptable_image_formats, show_size=show_size, verbose=verbose)
+    return listdir(DIR=DIR, recursive=recursive, use_fullpath=use_fullpath, ext = _acceptable_image_formats, verbose=verbose, every=every)
 
 
-def list_videos(DIR, recursive=True, use_fullpath=False, show_size=False, verbose=True) -> List[str]:
+def list_videos(DIR, recursive=True, use_fullpath=False, verbose=True, every : int = 1000) -> List[str]:
     r"""
         Lists all video files within a specific directory (and sub-directories if `recursive=True`)
     
@@ -68,7 +68,7 @@ def list_videos(DIR, recursive=True, use_fullpath=False, show_size=False, verbos
 
     """
 
-    return listdir(DIR=DIR, recursive=recursive, use_fullpath=use_fullpath, ext = _acceptable_video_formats, show_size=show_size, verbose=verbose)
+    return listdir(DIR=DIR, recursive=recursive, use_fullpath=use_fullpath, ext = _acceptable_video_formats, verbose=verbose, every=every)
 
 
 def listdir(
@@ -76,8 +76,8 @@ def listdir(
         recursive : bool = False, 
         use_fullpath: bool = False, 
         ext : Union[str, List[str]] = None, 
-        show_size : bool = False, 
-        verbose : bool = True
+        verbose : bool = True,
+        every : int = 1000
     ) -> List[str]:
     r"""
         Lists all files within a specific directory (and sub-directories if `recursive=True`).
@@ -89,7 +89,8 @@ def listdir(
         use_fullpath (bool): Include full filepaths in the returned list (default = False)
         ext (str, list(str), tuple(str)): Filter by extension names.
         show_size (bool): Prints the disk size of the files (default = False)
-        verbose(bool): Print info
+        verbose (bool): Print info
+        every (int): If ``verbose = True``, logging info is displayed after every `every` times.
     
     Returns:
         files (list): List of names (or full filepaths if `use_fullpath=True`) of the files
@@ -103,7 +104,7 @@ def listdir(
         raise ValueError('recursive must be a boolean')
 
     if not isinstance(use_fullpath, bool):
-        raise ValueError('use_fullpath must be a boolean')
+        raise TypeError('use_fullpath must be a boolean')
 
     if ext is not None:
         if not isinstance(ext, (str, list, tuple)):
@@ -113,49 +114,54 @@ def listdir(
             for i in ext:
                 if not isinstance(i, str):
                     raise TypeError("`ext` must be a homogenous list of `str`")
-
-    if not isinstance(show_size, bool):
-        raise ValueError('show_size must be a boolean')
     
     if not isinstance(verbose, bool):
-        raise ValueError('verbose must be a boolean')
+        raise TypeError('verbose must be a boolean')
+    
+    if not isinstance(every, int):
+        raise TypeError("`every` must be an int")
 
     dirs : list = []
     count_files : int = 0
-    size_dirs_list : int = 0
     
+    start = time()
+    count = 0
     if recursive:
         for root, _, files in os.walk(DIR):
             for file in files:
                 if ext is not None and not file.endswith(ext):
                     continue
+                count += 1
                 fullpath = join(root, file).replace('\\', '/')
-                size_dirs_list += get_size(fullpath, disp_format='mb')
                 if use_fullpath:
                     dirs.append(fullpath)
                 else:
                     dirs.append(file)
 
+                if verbose is True and count % every == 0:
+                    print(f"[INFO] At {count} files") # come up with a better log message!
+
     else:
         for file in os.listdir(DIR):
             if ext is not None and not file.endswith(ext):
                 continue
+            count += 1
             fullpath = join(DIR, file).replace('\\', '/')
-            size_dirs_list += get_size(fullpath, disp_format='mb')
             if use_fullpath:
                 dirs.append(fullpath)
             else:
                 dirs.append(file)
-
-    if verbose:
+            
+            if verbose is True and count % every == 0:
+                print(f"[INFO] At {count} files") # come up with a better log message!
+    end = time()
+    
+    if verbose is True:
         count_files = len(dirs)
         if count_files == 1:
-            print(f'[INFO] {count_files} file found')
+            print(f'[INFO] {count_files} file found in {end-start}s')
         else:
-            print(f'[INFO] {count_files} files found')
-
-        if show_size:
-            print(f'[INFO] Total disk size of files were {size_dirs_list:.2f}Mb ')
+            print(f'[INFO] {count_files} files found in {end-start}s')
 
     return dirs
 
@@ -174,7 +180,7 @@ def is_image(path) -> bool:
     """
 
     if not isinstance(path, str):
-        raise ValueError('path must be a string')
+        raise TypeError('path must be a string')
 
     if path.endswith(_acceptable_image_formats):
         return True 
